@@ -28,6 +28,7 @@ class Assignment(component.Component):
             grade_group_students_individually=None, rubric=None,
             rubric_settings=None, position=None, description=None,
             free_form_criterion_comments=None, assignment_group=None,
+            notify_of_update=None,
             filename=""):
         super().__init__(create_path=ASSIGNMENTS_PATH,
                 update_path=ASSIGNMENT_PATH, db_table=ASSIGNMENTS_TABLE,
@@ -60,6 +61,7 @@ class Assignment(component.Component):
             self.description = helpers.md2html(description.strip())
         else:
             self.description = description
+        self.notify_of_update = notify_of_update
         # easel-managed attrs
         # local variable has to be called assignment_group (clashes with module
         # name) to match the yaml and Canvas response
@@ -68,14 +70,6 @@ class Assignment(component.Component):
     def get_assignment_group_id(self, db, course_id):
         if self.assignment_group:
             ags = db.table(assignment_group.ASSIGN_GROUPS_TABLE)
-            # TODO: if a user initially pulls everything from a past course and
-            # then, instead of pushing everything at once to the new course,
-            # pushes an individual assignment, the assignment group it belongs
-            # to will not be found and throw the below error. But it should be
-            # capable of resolving the id for the name at that point because it
-            # pulled the info to the file. The solution is probably just to
-            # save the component to the db (in easel/commands.py in cmd_pull
-            # about line 183 or so.
             results = ags.search(tinydb.Query().name == self.assignment_group)
             if not results:
                 raise ValueError(f"failed to find AssignmentGroup called '{self.assignment_group}'")
