@@ -156,15 +156,9 @@ def cmd_pull(db, args):
 
             # local versions
             for child_path in os.listdir(component_filepath):
-                # TODO: anytime we call listdir like this, it might
-                # unintentionally pull in files other than the component yaml
-                # files. this would cause an error so you probably want to only
-                # listdir on yaml files or something like that
                 if not component_filepath.startswith("files"):
                     component = helpers_yaml.read(component_filepath + '/' +
                             child_path)
-                    # TODO: also, if the above file doesn't exist, helpers_yaml
-                    # will return None and break the next line
                     local[component.filename] = component
 
             # request remote versions
@@ -242,6 +236,10 @@ def cmd_push(db, args):
                         print(f"pushing {component} to {course_.name} ({course_.canvas_id})")
                         component.push(db, course_, args.dry_run)
 
+        elif component_filepath.startswith("files"):
+            for course_ in args.course:
+                files.push(db, course_, component_filepath, args.hidden,
+                        args.dry_run)
         else:
             for course_ in args.course:
                 if component_filepath == "syllabus.md":
@@ -257,3 +255,36 @@ def cmd_push(db, args):
                         # not a yaml file so assume it's a file/dir to upload
                         files.push(db, course_, component_filepath,
                                 args.hidden, args.dry_run)
+
+def cmd_md(db, args):
+    if not args.components:
+        args.components = ["syllabus.md", "assignment_groups", "assignments",
+                "files", "pages", "quizzes", "modules"]
+
+    for component_filepath in args.components:
+        if component_filepath.endswith("*"):
+            component_filepath = component_filepath[:-1]
+        if component_filepath.endswith("/"):
+            component_filepath = component_filepath[:-1]
+
+        if os.path.isdir(component_filepath) and not component_filepath.startswith("files"):
+            if component_filepath not in helpers.DIRS:
+                logging.error("Invalid directory: "+component_filepath)
+                continue
+
+            for child_path in os.listdir(component_filepath):
+                full_child_path = component_filepath + '/' + child_path
+                component = helpers_yaml.read(full_child_path)
+                print(component.md())
+        else:
+            if component_filepath == "syllabus.md":
+                f = open("syllabus.md")
+                print(helpers.md2html(f.read()))
+                f.close()
+            else:
+                component = helpers_yaml.read(component_filepath)
+                if isinstance(component, list):
+                    for obj in component:
+                        print("\n\n*****\n", obj.md())
+                else:
+                    print(component.md())
